#
# spec file for package python-pygraphviz
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pygraphviz
Version:        1.4rc1
Release:        lp151.2.5
Url:            http://networkx.lanl.gov/pygraphviz
Summary:        Python interface to Graphviz
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/p/pygraphviz/pygraphviz-%{version}.tar.gz
# PATCH-FIX-UPSTREAM docdir.patch
Patch:          docdir.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  graphviz-devel >= 2.16
BuildRequires:  pkg-config
BuildRequires:  swig
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
# Needed even without tests
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
Requires:       graphviz >= 2.16
%python_subpackages

%description
A Python wrapper for the Graphviz Agraph data structure.
PyGraphviz can be used to create and draw networks and graphs with Graphviz.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module pygraphviz-doc = %{version}}

%description -n %{name}-doc
This package provides documentation and help files for %{name}

%prep
%setup -q -n pygraphviz-%{version}
%patch

%build
# Need command-line flags only available in install

%install
export CFLAGS="%{optflags}"
%python_exec setup.py install -O1 --force --root %{buildroot} --prefix %{_prefix} --include-path %{_includedir}/graphviz/ --library-path %{_libdir}/graphviz/

%{python_expand pushd %{buildroot}%{$python_sitearch}
# Fix wrong-script-interpreter
sed -i "s|#!/usr/bin/env python|#!%__$python|" pygraphviz/tests/test.py
chmod a+x pygraphviz/tests/test.py
# Deduplicating files can generate a RPMLINT warning for pyc mtime
$python -m compileall -d %{$python_sitearch} pygraphviz/tests/
$python -O -m compileall -d %{$python_sitearch} pygraphviz/tests/
%fdupes .
popd
}

%if %{with tests}
%check
pushd examples
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -c "import pygraphviz;pygraphviz.test()"
}
popd
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{python_sitearch}/pygraphviz/
%{python_sitearch}/pygraphviz-%{version}-py*.egg-info

%files -n %{name}-doc
%defattr(-,root,root,-)
%doc LICENSE
%{_docdir}/pygraphviz-%{version}

%changelog
* Sun Aug  6 2017 toddrme2178@gmail.com
- Fix shebangs
* Wed May 17 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL
- Update to version 1.4rc1
  * No upstream changelog
* Wed Jun 15 2016 toddrme2178@gmail.com
- Update to 1.3.1
  - Update manifest to include missing files
- Update to 1.3
  - Python 3 support
  - Encoding bugfixes
- Rebase docdir.patch
* Fri Mar 28 2014 speilicke@suse.com
- Set license to BSD-3-Clause according to legal
* Fri Dec  6 2013 toddrme2178@gmail.com
- Update to 1.2
  * Quote Graphviz program names to work with space (Windows fix)
  * Keep name in reverse()
- Require graphviz-python
* Wed May 23 2012 toddrme2178@gmail.com
- Clean up spec file
- Update to version 1.1
  * Added unicode support for handling non-ASCII characters
  * Better handling of user data on initialization of AGraph() object to guess input type (AGraph object, file, dict-of-dicts, file)
  * Add sfdp to layout options
- Update to version 1..0.0
  * Added to_string() and from_string methods
  * Interface to graphviz “acyclic” and “tred”
  * Better handling of user data on initialization of AGraph() object to guess input type (AGraph object, file, dict-of-dicts, file)
  * Add handling of default attributes for subgraphs
  * Improved error handling when using non-string data
  * Fix bug in default attribute handling
  * Make sure file handles are closed correctly
* Sat Mar 26 2011 alexandre@exatati.com.br
- Regenerate spec file with py2pack;
- Bzip2 source code;
- Add docdir.patch to fix documentation path.
* Fri Oct  9 2009 alexandre@exatati.com.br
- Initial package (0.99.1) for openSUSE.
